@@ -1,5 +1,5 @@
 //    HOTELDRUID
-//    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+//    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 //
 //    This program is free software: you can redistribute it and/or modify
 //    it under the terms of the GNU Affero General Public License as published by
@@ -1112,3 +1112,125 @@ cont_vis.innerHTML = testo;
 return false;
 } // fine function apri_vis
 
+
+
+// funzioni tabella periodi e tariffe
+
+function append_inputs_from_form (idform_from,idform_to,app_hidden) {
+var form1 = document.getElementById(idform_from);
+var form2 = document.getElementById(idform_to);
+if (form1 && form2) {
+var el = new Array();
+for (var i=0 ; i < form1.length ; i++) {
+if (form1.elements[i].type != 'hidden' || app_hidden) {
+el[i] = document.createElement('input');
+el[i].type = 'hidden';
+el[i].name = form1.elements[i].name;
+el[i].value = form1.elements[i].value;
+form2.appendChild(el[i]);
+}
+} // for i
+}
+} // fine function append_inputs_from_form
+
+
+
+function mod_prezzo_cella (idc) {
+var cella = document.getElementById(idc);
+var prez1 = '';
+var prez2 = '';
+var mos_p = 0;
+var molt_p = 0;
+var val_pr = cella.innerHTML;
+cella.onclick = '';
+cella.title = '';
+var size_p1 = 8;
+if (idc.substr(-4) == 'pmin') size_p1 = 3;
+if (val_pr != '&nbsp;') {
+if (size_p1 == 3) prez1 = val_pr.split('&')[0];
+else {
+var val_pr_v = val_pr.split(' + ');
+if (val_pr_v.length == 1 && val_pr_v[0].indexOf('*p') >= 0) {
+val_pr_v[1] = val_pr_v[0];
+val_pr_v[0] = '';
+}
+var prez1_v = val_pr_v[0].split('*');
+prez1 = prez1_v[0];
+if (val_pr_v[1]) {
+var prez2_v = val_pr_v[1].split('*');
+prez2 = prez2_v[0];
+}
+}
+}
+if (prez1 == '&nbsp;') prez1 = '';
+if (prez1.match(/\.[0-9]{3,3}/)) prez1 = prez1.replace('.','');
+if (prez1.match(/\,[0-9]{3,3}/)) prez1 = prez1.replace(',','');
+var tar = idc.split('tar');
+if (prez1 && tab_tariffe && tar_per_app[tar[1]] && size_p1 == 8) prez1 = (prez1 / tar_per_app[tar[1]].substr(1));
+var nval = '<input id="p1'+idc+'" type="text" name="'+idc+'" value="'+prez1+'" onfocus="this.value = this.value;" size="'+size_p1+'">';
+if (tar_per_app[tar[1]]) nval += tar_per_app[tar[1]];
+if (prez2 == '') if (tar_per_pers[tar[1]]) prez2 = '&nbsp;';
+if (prez2 != '') {
+if (prez2 == '&nbsp;') prez2 = '';
+if (prez2.match(/\.[0-9]{3,3}/)) prez2 = prez2.replace('.','');
+if (prez2.match(/\,[0-9]{3,3}/)) prez2 = prez2.replace(',','');
+nval += ' + <input type="text" name="'+idc+'p" value="'+prez2+'" size="6">*p';
+}
+cella.innerHTML = nval;
+cella = document.getElementById('p1'+idc)
+cella.selectionStart = cella.selectionEnd = cella.value.length;
+cella.focus();
+
+var form_tpt = document.getElementById('f_tpt');
+var mel = document.createElement('input');
+mel.type = 'hidden';
+mel.name = "mod_"+idc;
+mel.value = '1';
+form_tpt.appendChild(mel);
+
+if (!subm_tpt) {
+subm_tpt = 1;
+mel = document.createElement('input');
+mel.type = 'hidden';
+mel.name = 'ins_form_tabella';
+mel.value = 'SI';
+form_tpt.appendChild(mel);
+form_tpt.onsubmit = new Function("append_inputs_from_form('f_tpt0','f_tpt',0);");
+var form_tpt0 = document.getElementById('f_tpt0');
+if (form_tpt0) form_tpt0.onsubmit = new Function("append_inputs_from_form('f_tpt','f_tpt0',1);");
+var subm_b_tpt = document.getElementById('but_tpt');
+if (document.getElementById('modi')) subm_b_tpt.innerHTML = frase_mod_prezzi_tpt;
+else {
+subm_b_tpt.innerHTML = '<div>'+frase_mod_prezzi_tpt+'</div>';
+subm_b_tpt.id = 'modi';
+}
+if (tab_tariffe) form_tpt.action = 'visualizza_tabelle.php';
+if (typeof replica_tasti === "function") replica_tasti();
+} // if
+} // fine function mod_prezzo_cella
+
+
+
+function attiva_mod_prezzi_cella () {
+var n0 = 0;
+var n1 = 0;
+var n2 = 0;
+var caselle = '';
+var tabella = '';
+var righe = '';
+for (n0 = 1 ; n0 <= num_tab_per_tar ; n0++) {
+tabella = document.getElementById('t_pertar'+n0);
+righe = tabella.childNodes[0].childNodes;
+for (n1 = 0 ; n1 < righe.length ; n1++) {
+caselle = righe[n1].childNodes;
+for (n2 = 1 ; n2 < caselle.length ; n2++) {
+if (caselle[n2].id && caselle[n2].id.substr(0,3) == 'per') {
+caselle[n2].onclick = new Function("mod_prezzo_cella('"+caselle[n2].id+"');");
+caselle[n2].title = fr_premere_per_modificare;
+} // if
+} // for n2
+} // for n1
+} // for n0
+} // fine function attiva_mod_prezzi_cella
+
+
