@@ -80,7 +80,9 @@ $num_dati_relcliente = numlin_query($dati_relcliente);
 for ($num2 = 0 ; $num2 < $num_dati_relcliente ; $num2++) {
 ${"campo_personalizzato_".risul_query($dati_relcliente,$num2,'testo1')."_".$num_c} = risul_query($dati_relcliente,$num2,'testo3');
 } # fine for $num2
+chiudi_query($dati_relcliente);
 } # fine if (($vedi_clienti != "PROPRI" and...
+chiudi_query($dati_cliente);
 } # fine for $num1
 
 $lista_clienti = $lista_c;
