@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2017 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -113,12 +113,16 @@ $files_sorgente = array(
 'includes/funzioni_log.php',
 'includes/funzioni_menu.php',
 'includes/funzioni_mod_prenota.php',
+'includes/funzioni_mysql_extra.php',
+'includes/funzioni_mysqli_extra.php',
 'includes/funzioni_mysqli.php',
 'includes/funzioni_mysql.php',
 'includes/funzioni.php',
+'includes/funzioni_postgresql_extra.php',
 'includes/funzioni_postgresql.php',
 'includes/funzioni_quadro_disp.php',
 'includes/funzioni_relutenti.php',
+'includes/funzioni_sqlite_extra.php',
 'includes/funzioni_sqlite.php',
 'includes/funzioni_tariffe.php',
 'includes/funzioni_testo.php',
@@ -233,6 +237,7 @@ $files_sorgente = array(
 'includes/lang/es/visualizza_contratto_var.php',
 'includes/lang/es/visualizza_tabelle.php',
 'includes/templates/',
+'includes/templates/aggiorna_modelli.php',
 'includes/templates/frasi_mod_disp.php',
 'includes/templates/funzioni_mod_disp.php',
 'includes/templates/funzioni_modelli.php',
