@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -53,14 +53,16 @@ $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 
 #@include("./includes/costanti.php");
 #@include(C_DATI_PATH."/costanti.php");
-define('C_PHPR_VERSIONE_NUM',2.30);
-define('C_PHPR_VERSIONE_TXT',"2.3.0");
+define('C_PHPR_VERSIONE_NUM',2.32);
+define('C_PHPR_VERSIONE_TXT',"2.3.2");
 
 if (!function_exists('utf8_encode')) {
 function utf8_encode ($testo) { return ($testo); }
 function utf8_decode ($testo) { return ($testo); }
 } # fine if (!function_exists('utf8_encode'))
 
+$id_sessione = htmlspecialchars($id_sessione);
+
 # Se non si specifica nessun anno uso l'attuale
 if (@is_file(C_DATI_PATH."/versione.php")) include_once(C_DATI_PATH."/versione.php");
 elseif (!defined('C_DIFF_ORE')) define('C_DIFF_ORE',0);
@@ -304,7 +306,7 @@ $parti[1] = round($parti[1]);
 $num = $parti[0].".".$parti[1];
 settype ($num,'double');
 } # fine if ($parti[1])
-else $num = $parti[0];
+else $num = (int) $parti[0];
 } # fine if (count($parti) == 2)
 
 return $num;
@@ -393,7 +395,10 @@ else $lingua_mex = "ita";
 $nome_utente_login = "";
 
 
-if (!is_file(C_DATI_PATH."/abilita_login")) $id_utente = 1;
+if (!is_file(C_DATI_PATH."/abilita_login")) {
+if ($pag == "inizio.php" or $pag == "creadb.php" or @is_file(C_DATI_PATH."/selectperiodi$anno.1.php")) $id_utente = 1;
+else echo "<br>The requested year does not exists.<br><br><a href=\"./inizio.php\">Go back</a><br>";
+} # fine if (!is_file(C_DATI_PATH."/abilita_login"))
 
 else {
 
@@ -896,6 +901,7 @@ else echo "$js += '".str_replace("\n","\\\n",$out)."';
 $last_dates_menu = $file;
 
 } # fine function mostra_menu_date
+if ($mos_tut_dat) $mos_tut_dat = "SI";
 
 
 
@@ -925,34 +931,16 @@ if (function_exists('ob_flush')) ob_flush();
 
 
 
-/*
-function aggiorna_interconnessioni ($nome_funz1,$nome_funz2,$anno,$PHPR_TAB_PRE,$lock) {
+function controlla_pag_origine ($origine) {
 
-$file_interconnessioni = C_DATI_PATH."/dati_interconnessioni.php";
-if (@is_file($file_interconnessioni)) {
-include($file_interconnessioni);
-if (@is_array($ic_present)) {
-$interconn_dir = opendir("./includes/interconnect/");
-while ($mod_ext = readdir($interconn_dir)) {
-if ($mod_ext != "." and $mod_ext != ".." and @is_dir("./includes/interconnect/$mod_ext")) {
-include("./includes/interconnect/$mod_ext/name.php");
-if ($ic_present[$interconnection_name] == "SI") {
-$funz_agg_interconn = $nome_funz1.$interconnection_name;
-if (!function_exists($funz_agg_interconn)) include("./includes/interconnect/$mod_ext/functions.php");
-$funz_agg_interconn($file_interconnessioni,$anno,$PHPR_TAB_PRE,$lock);
-if ($nome_funz2) {
-$funz_agg_interconn = $nome_funz2.$interconnection_name;
-$funz_agg_interconn($file_interconnessioni,$anno,$PHPR_TAB_PRE,$lock);
-} # fine if ($nome_funz2)
-} # fine if ($ic_present[$interconnection_name] == "SI")
-} # fine if ($modello_ext != "." and $modello_ext != ".." and...
-} # fine while ($mod_ext = readdir($interconn_dir))
-closedir($interconn_dir);
-} # fine if (@is_array($ic_present))
-} # fine if (@is_file($file_interconnessioni))
+$origine = trim($origine);
+if (substr($origine,0,2) == "./") $origine = substr($origine,2);
+if (strstr($origine,"http") or strstr($origine,"..") or strstr($origine,"/") or strstr($origine,"\\")) $origine = "inizio.php";
+
+return str_replace("\"","",str_replace(">","",str_replace("<","",$origine)));
+
+} # fine function controlla_pag_origine
 
-} # fine function aggiorna_interconnessioni
-*/
 
 
 
