@@ -121,6 +121,11 @@ case "Benvenuto a HOTELDRUID":  		$messaggio = "Welcome to HOTELDRUID"; break;
 case "Scegli la lingua":  			$messaggio = "Choose the language"; break;
 case "crea il database":  			$messaggio = "create database"; break;
 case "Promemoria":  				$messaggio = "Reminder"; break;
+case "Questo utente non ha i privilegi per creare nuovi anni":	$messaggio = "This user has no privileges to create new years"; break;
+case "Avviso":  				$messaggio = "Warning"; break;
+case "nel database sono ancora disponibili periodi solo per meno di":	$messaggio = "in the database there are still available periods for only less than"; break;
+case "mesi":  					$messaggio = "months"; break;
+case "OK, ho capito":  				$messaggio = "OK, got it"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
