@@ -36,6 +36,8 @@ case "nella pagina delle interconnessioni":  	$messaggio = "in interconnections
 case "Modifica la regola di assegnazione":  	$messaggio = "Modify the assignment rule"; break;
 case "La prenotazione cancellata non era presente nel database":	$messaggio = "The deleted reservation was not present in the database"; break;
 case "gruppo":  				$messaggio = "group"; break;
+case "Attenzione":  				$messaggio = "Warning"; break;
+case "carta di credito non salvata":  		$messaggio = "credit card not saved"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
