@@ -86,6 +86,31 @@ case "Estensione con cui vedere e scaricare il documento":	$messaggio = "Extensi
 case "predefinita":  				$messaggio = "default"; break;
 case "personalizzata":  			$messaggio = "custom"; break;
 case "Estensione cambiata":  			$messaggio = "Extension changed"; break;
+case "Considera questo documento come una API":	$messaggio = "Consider this document as an API"; break;
+case "Il documento verrà considerato come una API":	$messaggio = "The document will be considered as an API"; break;
+case "Il documento non verrà più considerato come una API":	$messaggio = "The document will no longer be considered as an API"; break;
+case "Password":  				$messaggio = "Password"; break;
+case "La password per la API del documento è stata cambiata":	$messaggio = "The password for document API has been changed"; break;
+case "Esempi di URL per chiamare il documento":	$messaggio = "Examples of URLs to call the document"; break;
+case "Tutte le prenotazioni dell'anno":  	$messaggio = "All reservations from year"; break;
+case "Mostra il documento come visto dall'utente":	$messaggio = "Show the document as seen by user"; break;
+case "L'utente per la API del documento è stato cambiato":	$messaggio = "The user for docuemnt API has been changed"; break;
+case "Nota":  					$messaggio = "Notice"; break;
+case "se la variabile":  			$messaggio = "if the variable"; break;
+case "non è presente nella URL allora verranno usate le prenotazioni dell'anno corrente":	$messaggio = "is not present in the URL then reservations from current year will be used"; break;
+case "Tutte le prenotazioni presenti dal":  	$messaggio = "All the reservations present from"; break;
+case "al":  					$messaggio = "to"; break;
+case "si possono usare anche le parole":  	$messaggio = "you can also use the words"; break;
+case "come date":  				$messaggio = "as dates"; break;
+case "e":  					$messaggio = "and"; break;
+case "Tutte le prenotazioni con numero dal":  	$messaggio = "All the reservations with numbers from"; break;
+case "Altri esempi dell'uso della variabile":  	$messaggio = "Other examples of the use of variable"; break;
+case "Tutte le prenotazioni inserite dal":  	$messaggio = "All reservations inserted from"; break;
+case "Tutti gli arrivi del":  			$messaggio = "All arrivals on"; break;
+case "Tutti le partenze del":  			$messaggio = "All departures on"; break;
+case "Tutti i clienti":  			$messaggio = "All the clients"; break;
+case "escludendo gli ospiti":  			$messaggio = "excluding guests"; break;
+case "inclusi gli ospiti":  			$messaggio = "including guests"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
