@@ -37,6 +37,7 @@ $trad_var['partita_iva'] = 'vat_number';
 $trad_var['num_persone'] = 'people_num';
 $trad_var['n_letti_agg'] = 'extra_beds_num';
 $trad_var['num_persone_tot'] = 'people_num_tot';
+$trad_var['num_persone_tipo'] = 'people_num_type';
 $trad_var['costo_tot'] = 'price_tot';
 $trad_var['caparra'] = 'deposit';
 $trad_var['resto_caparra'] = 'deposit_rest';
@@ -99,6 +100,7 @@ $trad_var['valore_giornaliero_max_costo_agg'] = 'extra_cost_max_daily_value';
 $trad_var['valore_giornaliero_max_costo_agg_p'] = 'extra_cost_max_daily_value_p';
 $trad_var['valore_giornaliero_max_costo_agg_sel'] = 'sel_extra_cost_max_daily_value';
 $trad_var['valore_giornaliero_max_costo_agg_sel_p'] = 'sel_extra_cost_max_daily_value_p';
+$trad_var['tipo_persona_costo_agg'] = 'extra_cost_person_type';
 $trad_var['data_inserimento_costo_agg'] = 'extra_cost_insertion_date';
 $trad_var['utente_inserimento_costo_agg'] = 'extra_cost_insertion_user';
 $trad_var['percentuale_tasse_costo_agg_sel'] = 'sel_extra_cost_taxes_percentage';
