@@ -358,6 +358,8 @@ case "presenti in data":  			$messaggio = "present on"; break;
 case "comprese partenze":  			$messaggio = "including departures"; break;
 case "escludere_da_totale_percentuale":  	$messaggio = "exclude_from_percentage_total"; break;
 case "da varie tariffe":  			$messaggio = "from different<br>rates"; break;
+case "senza letti aggiuntivi":  		$messaggio = "without extra beds"; break;
+case "Premere per modificare":  		$messaggio = "Click to modify"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
