@@ -311,6 +311,8 @@ case "modifica":  				$messaggio = "modificar"; break;
 case "In modo predefinito importa":  		$messaggio = "De manera predefinida importar"; break;
 case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè importati da altre tariffe":	$messaggio = "los precios de algunos períodos <em>no han sido insertados</em> porque importados desde otras tarifas"; break;
 case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "límite no considerado para las personas adicionales en las interconexiones"; break;
+case "Seleziona adesso questo costo anche per tutti gli utenti che non hanno privilegi per usare tutti i costi":	$messaggio = "Seleccionar ahora este coste también para todos los usuarios que no tienen privilegios para usar todos los costes"; break;
+case "Aggiungi adesso questo costo a tutte le pagine create per il sito web":	$messaggio = "Añadir ahora este coste a todas las páginas creadas para el sitio web"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
