@@ -20,6 +20,16 @@ case "aggiornata":  				$messaggio = "modificada"; break;
 case "commento":  				$messaggio = "comentario"; break;
 case "commento della foto":  			$messaggio = "comentario de la foto"; break;
 case "aggiornato":  				$messaggio = "modificado"; break;
+case "disponibilità":  				$messaggio = "disponibilidad"; break;
+case "permanenza min.":  			$messaggio = "estadía mín."; break;
+case "permanenza mass.":  			$messaggio = "estadía máx."; break;
+case "mostra disponibilità":  			$messaggio = "mostrar disponibilidad"; break;
+case "mostra permanenza minima":  		$messaggio = "mostrar estadía mínima"; break;
+case "raggruppa le date":  			$messaggio = "agurpar las fechas"; break;
+case "in modo predefinito per la tariffa":  	$messaggio = "por defecto para la tarifa"; break;
+case "Numero di persone predefinito per la tariffa":	$messaggio = "Número de personas por defecto para la tarifa"; break;
+case "Modifica i valori":  			$messaggio = "Modificar los valores"; break;
+case "non definito":  				$messaggio = "no definido"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
