@@ -37,6 +37,7 @@ $trad_var['partita_iva'] = 'certificado_identificacion_fiscal';
 $trad_var['num_persone'] = 'num_personas';
 $trad_var['n_letti_agg'] = 'num_camas_extras';
 $trad_var['num_persone_tot'] = 'num_personas_tot';
+$trad_var['num_persone_tipo'] = 'num_personas_tipo';
 $trad_var['costo_tot'] = 'coste_tot';
 $trad_var['caparra'] = 'fianza';
 $trad_var['resto_caparra'] = 'resto_fianza';
@@ -93,6 +94,7 @@ $trad_var['valore_giornaliero_max_costo_agg'] = 'valor_diario_max_coste_agna';
 $trad_var['valore_giornaliero_max_costo_agg_p'] = 'valor_diario_max_coste_agna_p';
 $trad_var['valore_giornaliero_max_costo_agg_sel'] = 'valor_diario_max_coste_agna_sel';
 $trad_var['valore_giornaliero_max_costo_agg_sel_p'] = 'valor_diario_max_coste_agna_sel_p';
+$trad_var['tipo_persona_costo_agg'] = 'tipo_persona_coste_agna';
 $trad_var['data_inserimento_costo_agg'] = 'fecha_insercion_coste_agna';
 $trad_var['utente_inserimento_costo_agg'] = 'usuario_insercion_coste_agna';
 $trad_var['percentuale_tasse_costo_agg_sel'] = 'porcentage_tasas_coste_agna_sel';
