@@ -71,7 +71,7 @@ case "finale":  				$messaggio = "síngulo"; break;
 case "Sempre":  				$messaggio = "Siempre"; break;
 case "Su_richiesta":  				$messaggio = "Bajo_pedido"; break;
 case "chidere_per_quanto_moltiplicare":  	$messaggio = "preguntar_por_cuanto_multiplicar"; break;
-case "cosiderare_come_letti_aggiuntivi":  	$messaggio = "considera_como_camas_extras"; break;
+case "cosiderare_come_letti_aggiuntivi":  	$messaggio = "considerar_como_camas_extras"; break;
 case "settimanale":  				$messaggio = "semanal"; break;
 case "giornaliero":  				$messaggio = "diario"; break;
 case "tutte":  				$messaggio = "todas"; break;
@@ -359,6 +359,8 @@ case "presenti in data":  			$messaggio = "presentes el"; break;
 case "comprese partenze":  			$messaggio = "incluyendo las salidas"; break;
 case "escludere_da_totale_percentuale":  	$messaggio = "excluir_del_total_para_porcentaje"; break;
 case "da varie tariffe":  			$messaggio = "desde varias<br>tarifas"; break;
+case "senza letti aggiuntivi":  		$messaggio = "sin camas extra"; break;
+case "Premere per modificare":  		$messaggio = "Hacer clic para modificar"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
