@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -954,7 +954,7 @@ $n_prenota_in_app_sett[$numapp][$num3] = "";
 } # fine for $num3
 $app_assegnabili_id2 = $app_assegnabili_id[$idprenotainperiodo];
 $app_assegnabili_id[$idprenotainperiodo] = "";
-$ap_ric = "";
+$ap_ric = array();
 for ($num3 = 0 ; $num3 < $dati_app['totapp'] ; $num3++) {
 $numapp2 = $dati_app['posizione'][$num3];
 if ($da_scambiare[$idprenotainperiodo][$numapp2] == "SI") {
@@ -1214,7 +1214,7 @@ $appartamento_vett[$app_richiesti_vett['id']] = $app_prenota_id[$id_prenota_lib]
 $app_prenota_id[$id_prenota_lib] = "";
 } # fine if ($fatto == "SI")
 else {
-$appartamento_vett[$app_richiesti_vett['id']] = "";
+if (@is_array($appartamento_vett)) $appartamento_vett[$app_richiesti_vett['id']] = "";
 aggiorna_app_aggiunti($limiti_var,$limiti_var_orig,$app_orig_prenota_id,$app_prenota_id,$inizio_prenota_id,$fine_prenota_id,$prenota_in_app_sett);
 } # fine else if ($fatto == "SI")
 $inizio_prenota_id[$id_prenota_lib] = "";
