@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -24,10 +24,10 @@
 
 global $template_theme_name,$template_theme_colors,$template_theme_values,$template_theme_html_pre,$template_theme_html_post;
 
-$template_theme_name = "";
-$template_theme_colors = "";
-$template_theme_html_pre = "";
-$template_theme_html_post = "";
+$template_theme_name = array();
+$template_theme_colors = array();
+$template_theme_html_pre = array();
+$template_theme_html_post = array();
 
 $template_theme_name[1] = "default";
 $template_theme_colors[1][1]['name'] = "font";
@@ -85,7 +85,7 @@ $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN
 <br><br>";
 $template_theme_html_post[1] = "
 ";
-if (C_NASCONDI_MARCA != "SI") $template_theme_html_post[1] .= "<small><small>Powered by 
+if (!defined('C_NASCONDI_MARCA') or C_NASCONDI_MARCA != "SI") $template_theme_html_post[1] .= "<small><small>Powered by 
 <a href=\"http://www.hoteldruid.com\" style=\"color: [theme_color_1];\">
 HotelDruid management software</a></small></small>";
 $template_theme_html_post[1] .= "</div>
