@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -186,12 +186,12 @@ if ($idprenota_origine) $anno = $anno - 1;
 if ($mostra_X == "SI") {
 if (@is_array($_POST)) reset($_POST);
 for($num1 = 0 ; $num1 < count($_POST); $num1++) {
-$lista_var_X .= "&amp;".key($_POST)."=".$_POST[key($_POST)];
+$lista_var_X .= "&amp;".key($_POST)."=".urlencode($_POST[key($_POST)]);
 next($_POST);
 } # fine for $num1
 if (@is_array($_GET)) reset($_GET);
 for($num1 = 0 ; $num1 < count($_GET); $num1++) {
-$lista_var_X .= "&amp;".key($_GET)."=".$_GET[key($_GET)];
+$lista_var_X .= "&amp;".key($_GET)."=".urlencode($_GET[key($_GET)]);
 next($_GET);
 } # fine for $num1
 if ($lista_var_X) {
